==> qore-1.19.2.tar.bz2: qore-1.19.2/docs/modules/QUnit/html/annotated_dup.js <==
var annotated_dup =
[
    [ "QUnit", "namespace_q_unit.html", [
      [ "AbstractTestResult", "class_q_unit_1_1_abstract_test_result.html", null ],
      [ "DependencyInjectedTest", "class_q_unit_1_1_dependency_injected_test.html", "class_q_unit_1_1_dependency_injected_test" ],
      [ "Test", "class_q_unit_1_1_test.html", "class_q_unit_1_1_test" ],
      [ "TestCase", "class_q_unit_1_1_test_case.html", "class_q_unit_1_1_test_case" ],
      [ "TestReporter", "class_q_unit_1_1_test_reporter.html", "class_q_unit_1_1_test_reporter" ],
      [ "TestResultExceptionDetail", "class_q_unit_1_1_test_result_exception_detail.html", "class_q_unit_1_1_test_result_exception_detail" ],
      [ "TestResultExceptionRegexp", "class_q_unit_1_1_test_result_exception_regexp.html", "class_q_unit_1_1_test_result_exception_regexp" ],
      [ "TestResultExceptionSubstring", "class_q_unit_1_1_test_result_exception_substring.html", "class_q_unit_1_1_test_result_exception_substring" ],
      [ "TestResultExceptionType", "class_q_unit_1_1_test_result_exception_type.html", "class_q_unit_1_1_test_result_exception_type" ],
      [ "TestResultFailure", "class_q_unit_1_1_test_result_failure.html", "class_q_unit_1_1_test_result_failure" ],
      [ "TestResultPartialHashMatch", "class_q_unit_1_1_test_result_partial_hash_match.html", null ],
      [ "TestResultSuccess", "class_q_unit_1_1_test_result_success.html", "class_q_unit_1_1_test_result_success" ],
      [ "TestResultValue", "class_q_unit_1_1_test_result_value.html", "class_q_unit_1_1_test_result_value" ]
    ] ]
];

==> qore-2.2.0.tar.bz2: qore-2.2.0/docs/modules/QUnit/html/annotated_dup.js <==
var annotated_dup =
[
    [ "QUnit", "namespace_q_unit.html", [
      [ "AbstractTestResult", "class_q_unit_1_1_abstract_test_result.html", null ],
      [ "DependencyInjectedTest", "class_q_unit_1_1_dependency_injected_test.html", "class_q_unit_1_1_dependency_injected_test" ],
      [ "Test", "class_q_unit_1_1_test.html", "class_q_unit_1_1_test" ],
      [ "TestCase", "class_q_unit_1_1_test_case.html", "class_q_unit_1_1_test_case" ],
      [ "TestReporter", "class_q_unit_1_1_test_reporter.html", "class_q_unit_1_1_test_reporter" ],
      [ "TestResultExceptionDetail", "class_q_unit_1_1_test_result_exception_detail.html", "class_q_unit_1_1_test_result_exception_detail" ],
      [ "TestResultExceptionRegexp", "class_q_unit_1_1_test_result_exception_regexp.html", "class_q_unit_1_1_test_result_exception_regexp" ],
      [ "TestResultExceptionSubstring", "class_q_unit_1_1_test_result_exception_substring.html", null ],
      [ "TestResultExceptionType", "class_q_unit_1_1_test_result_exception_type.html", "class_q_unit_1_1_test_result_exception_type" ],
      [ "TestResultFailure", "class_q_unit_1_1_test_result_failure.html", "class_q_unit_1_1_test_result_failure" ],
      [ "TestResultPartialHashMatch", "class_q_unit_1_1_test_result_partial_hash_match.html", null ],
      [ "TestResultSuccess", "class_q_unit_1_1_test_result_success.html", "class_q_unit_1_1_test_result_success" ],
      [ "TestResultValue", "class_q_unit_1_1_test_result_value.html", "class_q_unit_1_1_test_result_value" ]
    ] ]
];
